Learn R Programming

rechaRge (version 1.0.0)

KGE: KGE computation

Description

Compute the Kling-Gupta Efficiency coefficient which summarizes the discrepancy between observed values and the values expected under the model in question.

Usage

KGE(sim, obs)

Value

Kling-Gupta Efficiency between 'sim' and 'obs'

Arguments

sim

Simulated values

obs

Observed values

Examples

Run this code
sim <- c(0.5, 0.5, 10, 15, 0.5, 20, 25, 0.1, 15, 10)
obs <- c(1, 0.1, 0.1, 20, 0.6, 30, 20, 0.5, 30, 8)
rechaRge::KGE(sim, obs)

Run the code above in your browser using DataLab