compute_vertical_inflow_cell: Compute the vertical inflow and the potential evapotranspiration (PET) for a single cell
Description
Compute the vertical inflow and the potential evapotranspiration (PET) for a single cell
Usage
compute_vertical_inflow_cell(obj, input_dd)
Arguments
- obj
The HydroBudget object.
- input_dd
Spatially distributed daily precipitation and mean temperature time series in a single cell.